@@ -7,7 +7,7 @@ use DynaLoader ();
 
 use vars qw{ $VERSION @ISA @EXPORT_OK %EXPORT_TAGS };
 BEGIN {
-    $VERSION   = '0.31_02';
+    $VERSION   = '0.33_005';
     $VERSION   = eval $VERSION;
     @ISA       = qw{ Exporter DynaLoader };
     @EXPORT_OK = qw{
@@ -355,6 +355,13 @@ die $@ if $@;
 *zip         = \&mesh;
 *distinct    = \&uniq;
 
+# If pairwise is exported, let Perl "see" $a and $b in the caller's symbol table
+# so there won't be a "used only once" warning for those two symbols.
+if( eval{ caller(1)->can('pairwise'); 1; } ) {   # caller(1): eval adds a level.
+    no strict 'refs';
+    local ${ caller . '::a' }, ${ caller . '::b' }; # caller(0): importing pkg.
+}
+
 1;
 
 __END__
@@ -556,7 +563,7 @@ Returns the first element in LIST for which BLOCK evaluates to true. Each
 element of LIST is set to C<$_> in turn. Returns C<undef> if no such element
 has been found.
 
-C<first_val> is an alias for C<firstval>.
+C<first_value> is an alias for C<firstval>.
 
 =item lastval BLOCK LIST
 
@@ -566,7 +573,7 @@ Returns the last value in LIST for which BLOCK evaluates to true. Each element
 of LIST is set to C<$_> in turn. Returns C<undef> if no such element has been
 found.
 
-C<last_val> is an alias for C<lastval>.
+C<last_value> is an alias for C<lastval>.
 
 =item pairwise BLOCK ARRAY1 ARRAY2
 
@@ -606,7 +613,7 @@ the index of the last fetched set of values, as a scalar.
 Like each_array, but the arguments are references to arrays, not the
 plain arrays.
 
-=item natatime BLOCK LIST
+=item natatime EXPR, LIST
 
 Creates an array iterator, for looping over an array in chunks of
 C<$n> items at a time.  (n at a time, get it?).  An example is
